@@ -13,13 +13,13 @@ import Control.Applicative (
 #endif
   )
 #endif
-import Control.Monad (forM_)
+import Control.Monad (forM_, when)
 import Data.Either (partitionEithers)
 import Data.Tuple (swap)
 #if !MIN_VERSION_simple_cmd_args(0,1,7)
 import Options.Applicative (eitherReader, maybeReader, ReadM)
 #endif
-import SimpleCmd ((+-+))
+import SimpleCmd ((+-+), warning)
 import SimpleCmdArgs
 import System.IO (BufferMode(NoBuffering), hSetBuffering, stdout)
 
@@ -29,7 +29,7 @@ import List (listVersionsCmd)
 import Paths_fedora_repoquery (version)
 import Query (repoqueryCmd)
 import Release (showReleaseCmd, downloadServer)
-import Types (Channel(..), Mirror(..), Release (System), RepoSource(..), Verbosity(..),
+import Types (Mirror(..), Release (System), RepoSource(..), Verbosity(..),
               eitherRelease)
 
 data Command = Query [String] | CacheSize | CacheEmpties | List
@@ -49,15 +49,13 @@ main = do
     <*> switchWith 'T' "time" "Show time-stamp of repos"
     <*> (RepoSource
           <$> switchWith 'K' "koji" "Use Koji buildroot"
-          <*> (flagLongWith' ChanDevel "devel-channel" "Use eln development compose" <|>
-               flagLongWith ChanProd ChanTest "test-channel" "Use eln test compose [default: production]")
           <*> ((Mirror <$> strOptionWith 'm' "mirror" "URL" ("Fedora mirror [default: " ++ downloadServer ++ "]")) <|>
-               flagWith DownloadFpo DlFpo 'D' "dl" "Use dl.fp.o"))
+               flagWith DownloadFpo DlFpo 'd' "dl" "Use dl.fp.o"))
     <*> (flagWith' [Source] 's' "source" "Query source repos" <|>
          flagWith' allArchs 'A' "all-archs" "Query all (64 bit) arch repos" <|>
          many (optionWith (eitherReader eitherArch) 'a' "arch" "ARCH" ("Specify arch [default:" +-+ showArch sysarch ++ "]")))
     <*> switchWith 't' "testing" "Fedora updates-testing"
-    <*> switchWith 'd' "debug" "Show some debug output"
+    <*> switchWith 'D' "debug" "Show some debug output"
     <*> (flagWith' CacheSize 'z' "cache-size" "Show total dnf repo metadata cache disksize"
          <|> flagWith' CacheEmpties 'e' "cache-clean-empty" "Remove empty dnf caches"
          <|> flagWith' List 'l' "list" "List Fedora versions"
@@ -73,12 +71,14 @@ runMain sysarch dnf4 verbose dynredir time reposource archs testing debug comman
     Query relargs ->
       -- spanJust from utility-ht nicer but this gets us enough
       let (releases,args) = swap $ partitionEithers $ map eitherRelease relargs
-      in
+      in do
+        when (null releases && verbose /= Quiet) $
+          warning "(using system repos)"
         forM_ (if null releases then [System] else releases) $ \release ->
-        if null args
-        then if null archs
-             then showReleaseCmd debug dynredir reposource release sysarch Nothing testing
-             else forM_ archs $ \arch -> showReleaseCmd debug dynredir reposource release sysarch (Just arch) testing
-        else
-          let multiple = length releases > 1 || length archs > 1
-          in repoqueryCmd dnf4 debug verbose multiple dynredir time release reposource sysarch archs testing args
+          if null args
+          then if null archs
+               then showReleaseCmd debug dynredir reposource release sysarch Nothing testing
+               else forM_ archs $ \arch -> showReleaseCmd debug dynredir reposource release sysarch (Just arch) testing
+          else
+            let multiple = length releases > 1 || length archs > 1
+            in repoqueryCmd dnf4 debug verbose multiple dynredir time release reposource sysarch archs testing args
