@@ -6,12 +6,12 @@ module Query (
 
 import Control.Monad.Extra
 import Data.Char (isSpace)
-import qualified Data.List.Extra as L
+import Data.List.Extra
 import Data.Maybe (isJust, fromMaybe)
 import Safe (lastMay)
 import SimpleCmd (cmdLines)
 import System.Directory (doesFileExist, findExecutable)
-import System.FilePath (takeBaseName)
+import System.FilePath (takeBaseName, (<.>))
 
 import Arch
 import Common (warning)
@@ -36,7 +36,6 @@ pkgAttrsOptions =
     "supplements"
   ]
 
--- FIXME error if no testing repo
 repoqueryCmd :: Bool -> Bool -> Verbosity -> Bool -> Bool -> Bool -> Release
              -> RepoSource -> Arch -> [Arch] -> Bool -> [String] -> IO ()
 repoqueryCmd dnf4 debug verbose multiple dynredir checkdate release reposource sysarch archs testing args = do
@@ -57,7 +56,7 @@ repoqueryCmd dnf4 debug verbose multiple dynredir checkdate release reposource s
     rhsm <- doesFileExist "/etc/dnf/plugins/subscription-manager.conf"
     let cmdargs = "repoquery" :
                   -- for dnf5 does not suppress repodata downloading
-                  ["--quiet" | verbose /= Verbose] ++
+                  ["--quiet" | verbose /= Verbose || not debug] ++
                   -- https://bugzilla.redhat.com/show_bug.cgi?id=1876828
                   ["--disableplugin=subscription-manager" | rhsm] ++
                   (if qfAllowed then ["--qf", queryformat] else []) ++
@@ -72,27 +71,43 @@ repoqueryCmd dnf4 debug verbose multiple dynredir checkdate release reposource s
     res <- cmdLines dnf cmdargs
     unless (null res) $ do
       unless (not checkdate || release == System || multiple) $ warning ""
-      putStrLn $ L.intercalate "\n" res
+      putStrLn $ intercalate "\n" res
   where
     tweakedArgs dnf5 =
       if not dnf5
       then args
-      else tweakQf $ map tweakInfo args
+      else tweakQfOpt $ map tweakInfo args
       where
         -- dnf5 only has --info not -i
         tweakInfo "-i" = "--info"
         tweakInfo arg = arg
 
         -- dnf5 doesn't append \n to queryformat
-        tweakQf as@(x:y:rest) | x `elem` ["--qf","--queryformat"] =
-                                case lastMay y of
-                                  Just sp -> if isSpace sp
-                                             then as
-                                             else x : (y ++ "\n") : rest
-                                  Nothing -> as
-                              | otherwise = x : tweakQf (y:rest)
-        tweakQf xs = xs
+        tweakQfOpt (x:y:rest) | x `elem` ["--qf","--queryformat"] =
+                                   x : tweakQf y : rest
+                              | otherwise = x : tweakQfOpt (y:rest)
+        tweakQfOpt xs = xs
+
+        tweakQf qf =
+          expandQf qf ++
+          case lastMay qf of
+            Just lc -> if isSpace lc then "" else "\n"
+            Nothing -> ""
+
+        expandQf qf =
+          case lower qf of
+            "n" -> "%{name}"
+            "nv" -> "%{name}-%{version}"
+            "nvr" -> expandQf "nv" ++ "-%{release}"
+            "nvra" -> expandQf "nvr" <.> "%{arch}"
+            "envr" -> "%{epoch}:" ++ expandQf "nvr"
+            "envra" -> "%{epoch}:" ++ expandQf "nvra"
+            _ -> qf
 
 renderRepoConfig :: (String, URL) -> [String]
 renderRepoConfig (name, url) =
-  ["--repofrompath=" ++ name ++ "," ++ renderUrl Dir url, "--repo=" ++ name, "--setopt=" ++ name ++ ".metadata_expire=6h" ]
+  ["--repofrompath=" ++ name ++ "," ++ renderUrl Dir url,
+   "--repo=" ++ name,
+   "--setopt=" ++ name ++ ".metadata_expire=6h",
+   -- avoid failing silently for 404 etc
+   "--setopt=" ++ name ++ ".skip_if_unavailable=0"]
