@@ -18,7 +18,7 @@ fdrq (args,mpkg) = do
 
 -- copied from dl-fedora
 branched :: Int
-branched = 41
+branched = 42
 current, previous, prevprev, rawhide :: String
 current = show branched
 previous = show (branched - 1)
@@ -31,7 +31,9 @@ tests =
   ,(["-D","rawhide"], Nothing)
   ,([current], Nothing)
   ,([previous], Nothing)
-  ,([prevprev], Nothing)
+  ,(["eln"], Nothing)
+  ,(["epel9"], Nothing)
+  ,(["c10s"], Nothing)
   ,(["-T", "rawhide"], Just "coreutils")
   ,(["--dynamic", rawhide], Just "coreutils")
   ,(["-T", current], Just "gtk4")
@@ -40,6 +42,8 @@ tests =
   ,(["-t", previous], Just "podman")
   ,(["eln"], Just "ibus")
   ,(["epel9"], Just "ghc")
+  ,(["epel10"], Just "ghc")
+  ,(["epel10.0"], Just "ghc-srpm-macros")
   ,(["c10"], Just "bash")
   ,(["c9"], Just "kernel")
   ,(["rawhide", "--whatprovides"], Just "perl(Regexp::Pattern::License)")
